#ifndef  __SYSTEM_DEFINED
#define __SYSTEM_DEFINED

#include <cdefBF533.h>
#include <stdio.h>
#include <sys\exception.h>
#include <fract.h>
#include <complex.h>
#include <filter.h>

/********************************************************************************/
/***** Symbolic constants													*****/
/********************************************************************************/

// SYSTEM CONSTANTS  

#define CRYSTAL_CLK				   	 27000		// in kHz
#define CORE_CLK				   	378000		// in kHz
#define SYSTEM_CLK				   	126000		// in kHz

#define ADC_SPI_CLK				   	1000		// in kHz

#define BAUD_CONF					SYSTEM_CLK / ADC_SPI_CLK / 2

#define Number_of_ADC_bits		   	12
#define Number_of_ADC_channels   	1
#define Number_of_DAC_channels		1
#define Number_of_Samples   		512 		// Block size of words/channel to be DMA'd from ADC
#define Word_Size  					2			// data transfer size in Bytes
												// memory requirement for buffer is
												// Number_of_Samples * Number_of_ADCC_channels * Word_Size * 2 BYTES
												// (because of double buffer ping-pong scheme) 


// BACKGROUND TELEMETRY CHANNELS
//#define ENABLE_BTC						// include Background Telemetry Channel


// EZKIT and external FLASH constants
#define EZ_KIT


#define FLASHA_SRAM 			0x20240000		// base addr for memory space
#define FLASHA_CSIO 			0x20270000		// base addr for programmable IO ports
#define PORTA_DATA_OUT 			0x04			// offset
#define PORTB_DATA_OUT 			0x05			// offset
#define PORTA_DATA_DIR 			0x06			// offset
#define PORTB_DATA_DIR 			0x07			// offset
#define PPI_EXTENDER_CLK_BIT	5				// offset


/********************************************************************************/
/***** Prototypes															*****/
/********************************************************************************/
void InitInterrupts(void);
void initTimer(void);
void InitSDRAM(void);
void Init_AD9866(void);
void process();
void Set_PLL(short CoreCLOCK_multiplier, short SCLK_divider);
void InitSPI_for_AD9866(void);
unsigned char Write_Byte_to_AD9866(unsigned char AD9866_address, unsigned char AD9866_data);
unsigned char Read_Byte_from_AD9866(unsigned char AD9866_address);
void initTimer(void);


EX_INTERRUPT_HANDLER(Timer_ISR);

/********************************************************************************/
/***** Global variables														*****/
/***** All global variables are declared in main.c							*****/
/********************************************************************************/
extern volatile short sPPI_RxBuffer[];
extern volatile short sPPI_TxBuffer[];
extern short ping_pong;
extern short half;
extern short stage_initialized;
extern int interruptLatch;
struct sDMA_descriptor {struct sDMA_descriptor* next_descriptor;
					    volatile short *start_address;
};
typedef struct sDMA_descriptor tDMA_descriptor;

//extern tDMA_descriptor DMA_RX_first; // declaration
//extern tDMA_descriptor DMA_TX_first; // declaration


#endif

